@@ -1,3 +1,6 @@
+# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: t -*-
+# vi: set ft=python sts=4 ts=4 sw=4 noet :
+
 # This file is part of Fail2Ban.
 #
 # Fail2Ban is free software; you can redistribute it and/or modify
@@ -12,15 +15,15 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with Fail2Ban; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 # Author: Cyril Jaquier
 # 
-# $Revision: 731 $
+# $Revision$
 
 __author__ = "Cyril Jaquier"
-__version__ = "$Revision: 731 $"
-__date__ = "$Date: 2009-02-09 23:08:21 +0100 (Mon, 09 Feb 2009) $"
+__version__ = "$Revision$"
+__date__ = "$Date$"
 __copyright__ = "Copyright (c) 2004 Cyril Jaquier"
 __license__ = "GPL"
 
@@ -88,19 +91,22 @@ class FailManager:
 			self.__lock.acquire()
 			ip = ticket.getIP()
 			unixTime = ticket.getTime()
+			matches = ticket.getMatches()
 			if self.__failList.has_key(ip):
 				fData = self.__failList[ip]
 				if fData.getLastReset() < unixTime - self.__maxTime:
 					fData.setLastReset(unixTime)
 					fData.setRetry(0)
-				fData.inc()
+				fData.inc(matches)
 				fData.setLastTime(unixTime)
 			else:
 				fData = FailData()
-				fData.inc()
+				fData.inc(matches)
 				fData.setLastReset(unixTime)
 				fData.setLastTime(unixTime)
 				self.__failList[ip] = fData
+			logSys.debug("Currently have failures from %d IPs: %s"
+						 % (len(self.__failList), self.__failList.keys()))
 			self.__failTotal += 1
 		finally:
 			self.__lock.release()
@@ -134,7 +140,7 @@ class FailManager:
 				if data.getRetry() >= self.__maxRetry:
 					self.__delFailure(ip)
 					# Create a FailTicket from BanData
-					failTicket = FailTicket(ip, data.getLastTime())
+					failTicket = FailTicket(ip, data.getLastTime(), data.getMatches())
 					failTicket.setAttempt(data.getRetry())
 					return failTicket
 			raise FailManagerEmpty
