@@ -1,3 +1,6 @@
+# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: t -*-
+# vi: set ft=python sts=4 ts=4 sw=4 noet :
+
 # This file is part of Fail2Ban.
 #
 # Fail2Ban is free software; you can redistribute it and/or modify
@@ -12,16 +15,15 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with Fail2Ban; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-# Author: Cyril Jaquier
-# 
-# $Revision: 696 $
+# Author: Cyril Jaquier, Yaroslav Halchenko
+#
 
-__author__ = "Cyril Jaquier"
-__version__ = "$Revision: 696 $"
-__date__ = "$Date: 2008-05-19 23:05:32 +0200 (Mon, 19 May 2008) $"
-__copyright__ = "Copyright (c) 2004 Cyril Jaquier"
+__author__ = "Cyril Jaquier, Yaroslav Halchenko"
+__version__ = "$Revision$"
+__date__ = "$Date$"
+__copyright__ = "Copyright (c) 2004 Cyril Jaquier; 2012 Yaroslav Halchenko"
 __license__ = "GPL"
 
 from failmanager import FailManagerEmpty
@@ -47,7 +49,7 @@ class FilterPoll(FileFilter):
 	#
 	# Initialize the filter object with default values.
 	# @param jail the jail object
-	
+
 	def __init__(self, jail):
 		FileFilter.__init__(self, jail)
 		self.__modified = False
@@ -61,29 +63,19 @@ class FilterPoll(FileFilter):
 	#
 	# @param path log file path
 
-	def addLogPath(self, path, tail = False):
-		if self.containsLogPath(path):
-			logSys.error(path + " already exists")
-		else:
-			self.__lastModTime[path] = 0
-			self.__file404Cnt[path] = 0
-			FileFilter.addLogPath(self, path, tail)
-			logSys.info("Added logfile = %s" % path)	
-	
+	def _addLogPath(self, path):
+		self.__lastModTime[path] = 0
+		self.__file404Cnt[path] = 0
+
 	##
 	# Delete a log path
 	#
 	# @param path the log file to delete
-	
-	def delLogPath(self, path):
-		if not self.containsLogPath(path):
-			logSys.error(path + " is not monitored")
-		else:
-			del self.__lastModTime[path]
-			del self.__file404Cnt[path]
-			FileFilter.delLogPath(self, path)
-			logSys.info("Removed logfile = %s" % path)
-	
+
+	def _delLogPath(self, path):
+		del self.__lastModTime[path]
+		del self.__file404Cnt[path]
+
 	##
 	# Main loop.
 	#
@@ -97,8 +89,9 @@ class FilterPoll(FileFilter):
 			if not self.getIdle():
 				# Get file modification
 				for container in self.getLogPath():
-					if self.isModified(container.getFileName()):
-						self.getFailures(container.getFileName())
+					filename = container.getFileName()
+					if self.isModified(filename):
+						self.getFailures(filename)
 						self.__modified = True
 
 				if self.__modified:
@@ -113,7 +106,8 @@ class FilterPoll(FileFilter):
 				time.sleep(self.getSleepTime())
 			else:
 				time.sleep(self.getSleepTime())
-		logSys.debug(self.jail.getName() + ": filter terminated")
+		logSys.debug((self.jail and self.jail.getName() or "jailless") +
+					 " filter terminated")
 		return True
 
 	##
@@ -121,7 +115,7 @@ class FilterPoll(FileFilter):
 	#
 	# Checks if the log file has been modified using os.stat().
 	# @return True if log file has been modified
-	
+
 	def isModified(self, filename):
 		try:
 			logStats = os.stat(filename)
@@ -132,11 +126,15 @@ class FilterPoll(FileFilter):
 				logSys.debug(filename + " has been modified")
 				self.__lastModTime[filename] = logStats.st_mtime
 				return True
-		except OSError:
-			logSys.error("Unable to get stat on " + filename)
-			self.__file404Cnt[filename] = self.__file404Cnt[filename] + 1
+		except OSError, e:
+			logSys.error("Unable to get stat on %s because of: %s"
+						 % (filename, e))
+			self.__file404Cnt[filename] += 1
 			if self.__file404Cnt[filename] > 2:
-				logSys.warn("Too much read error. Set the jail idle")
-				self.jail.setIdle(True)
+				logSys.warn("Too many errors. Setting the jail idle")
+				if self.jail:
+					self.jail.setIdle(True)
+				else:
+					logSys.warn("No jail is assigned to %s" % self)
 				self.__file404Cnt[filename] = 0
 			return False
