@@ -55,7 +55,8 @@ class Transmitter:
 			ret = self.__commandHandler(command)
 			ack = 0, ret
 		except Exception, e:
-			logSys.warn("Invalid command: " + `command`)
+			logSys.warn("Command %r has failed. Received %r"
+						% (command, e))
 			ack = 1, e
 		return ack
 	
@@ -174,6 +175,9 @@ class Transmitter:
 		elif command[1] == "banip":
 			value = command[2]
 			return self.__server.setBanIP(name,value)
+		elif command[1] == "unbanip":
+			value = command[2]
+			return self.__server.setUnbanIP(name,value)
 		elif command[1] == "addaction":
 			value = command[2]
 			self.__server.addAction(name, value)
